==> flutter_agnes-1.0.4.tar.gz: lib/src/widgets/share/text_form_field_none_border.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TextFormFieldNoneBorder extends StatelessWidget {
  final String title;
  final bool isObscureText;
  final bool isNumber;
  final int maxLength;
  final TextEditingController controller;
  final int lines;
  final IconData icon;
  final Color colorIcon;
  final Color cursorColor;
  final TextStyle styleTitle;
  final List<TextInputFormatter> inputFormatters;
  final GestureTapCallback onTap;
  final ValueChanged<String> onChanged;
  final FocusNode focusNode;
  final ValueChanged<String> onFieldSubmitted;

  final TextAlign textAlign;
  final bool enabled;

  const TextFormFieldNoneBorder(
      {@required this.title,
      this.isObscureText = false,
      this.isNumber = false,
      this.textAlign = TextAlign.start,
      this.maxLength,
      this.controller,
      this.lines = 1,
      this.icon,
      this.colorIcon,
      this.cursorColor,
      this.styleTitle,
      this.enabled,
      this.focusNode,
      this.inputFormatters,
      this.onChanged,
      this.onFieldSubmitted,
      this.onTap,
      Key key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.symmetric(vertical: 2),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          SizedBox(
            height: 10,
          ),
          Text(
            title,
            style: styleTitle,
          ),
          SizedBox(
            height: 2,
          ),
          TextFormField(
              maxLines: lines,
              controller: controller,
              maxLength: maxLength,
              inputFormatters: inputFormatters,
              cursorColor: cursorColor,
              enabled: enabled,
              textAlign: textAlign,
              obscureText: isObscureText,
              keyboardType: isNumber ? TextInputType.number : TextInputType.text,
              decoration: InputDecoration(
                  prefixIcon: Icon(
                        icon,
                        color: colorIcon,
                      ) ??
                      null,
                  counterText: '',
                  border: InputBorder.none,
                  fillColor: Color(0xfff3f3f4),
                  filled: true),
              onTap: onTap,
              onChanged: onChanged,
              focusNode: focusNode,
              onFieldSubmitted: onFieldSubmitted)
        ],
      ),
    );
  }
}

==> flutter_agnes-1.0.6.tar.gz: lib/src/widgets/share/text_form_field_none_border.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TextFormFieldNoneBorder extends StatelessWidget {
  final String title;
  final bool isObscureText;
  final bool isNumber;
  final int maxLength;
  final TextEditingController controller;
  final int lines;
  final IconData icon;
  final Color colorIcon;
  final Color cursorColor;
  final TextStyle styleTitle;
  final List<TextInputFormatter> inputFormatters;
  final GestureTapCallback onTap;
  final ValueChanged<String> onChanged;
  final FocusNode focusNode;
  final ValueChanged<String> onFieldSubmitted;
  final FormFieldValidator<String> validator;
  final TextAlign textAlign;
  final bool enabled;

  const TextFormFieldNoneBorder({@required this.title,
    this.isObscureText = false,
    this.isNumber = false,
    this.textAlign = TextAlign.start,
    this.maxLength,
    this.controller,
    this.lines = 1,
    this.icon,
    this.colorIcon,
    this.cursorColor,
    this.styleTitle,
    this.enabled,
    this.focusNode,
    this.inputFormatters,
    this.onChanged,
    this.onFieldSubmitted,
    this.onTap,
    this.validator,
    Key key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.symmetric(vertical: 2),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          SizedBox(
            height: 10,
          ),
          Text(
            title,
            style: styleTitle,
          ),
          SizedBox(
            height: 2,
          ),
          TextFormField(
              maxLines: lines,
              controller: controller,
              maxLength: maxLength,
              validator: validator,
              inputFormatters: inputFormatters,
              cursorColor: cursorColor,
              enabled: enabled,
              textAlign: textAlign,
              obscureText: isObscureText,
              keyboardType: isNumber ? TextInputType.number : TextInputType.text,
              decoration: InputDecoration(
                  prefixIcon: Icon(
                    icon,
                    color: colorIcon,
                  ) ??
                      null,
                  counterText: '',
                  border: InputBorder.none,
                  fillColor: Color(0xfff3f3f4),
                  filled: true),
              onTap: onTap,
              onChanged: onChanged,
              focusNode: focusNode,
              onFieldSubmitted: onFieldSubmitted)
        ],
      ),
    );
  }
}
